//!```
//!  _____       _              _   _ _              _            
//! /  ___|     | |            | | | | |            (_)           
//! \ `--.  __ _| |_   ____ _  | | | | | ___ __ __ _ _ _ __   ___
//!  `--. \/ _` | \ \ / / _` | | | | | |/ / '__/ _` | | '_ \ / _ \
//! /\__/ / (_| | |\ V / (_| | | |_| |   <| | | (_| | | | | |  __/
//! \____/ \__,_|_| \_/ \__,_|  \___/|_|\_\_|  \__,_|_|_| |_|\___|
//!```
pub trait RussianWarship {
    /// [The only thing necessary for the triumph of evil is for good men to do nothing](https://twitter.com/Ukraine/status/1497594592438497282)
    fn go_fuck_your(self);
}
